#
# spec file for package vgrep
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Remove stripping of Go binaries.
%define __arch_install_post export NO_BRP_STRIP_DEBUG=true
# Project name when using go tooling.
%define project github.com/vrothberg/vgrep
Name:           vgrep
Version:        2.6.1
Release:        bp155.1.6
Summary:        Frontend for git-grep and grep
License:        GPL-3.0-only
Group:          Productivity/Text/Utilities
URL:            https://github.com/vrothberg/vgrep
Source0:        https://github.com/vrothberg/vgrep/archive/v%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  golang(API) >= 1.17
Requires:       git-core
Requires:       grep

%description
vgrep is a command-line tool to search textual patterns in directories. It
serves as a frontend to grep and git-grep and allows to open the indexed
matching lines in a user-specified editor. vgrep is inspired by the ancient
cgvg scripts but extended to perform further operations such as listing
statistics of files and directory trees or showing the context lines before and
after the matches.

%prep
%autosetup

%build

# We can't use symlinks here because go-list gets confused by symlinks, so we
# have to copy the source to $HOME/go and then use that as the GOPATH.
export GOPATH=$HOME/go
mkdir -pv $HOME/go/src/%{project}
rm -rf $HOME/go/src/%{project}/*
cp -avr * $HOME/go/src/%{project}

# Build the binary.
cd $HOME/go/src/%{project}
go build -mod=vendor -o ./build/vgrep -buildmode=pie -ldflags "-s -w -X main.version=%{version}"

%install
# Install the binary.
install -D -m 0755 $HOME/go/src/%{project}/build/%{name} "%{buildroot}/%{_bindir}/%{name}"

%fdupes %{buildroot}/%{_prefix}

%files
%license LICENSE
%{_bindir}/%{name}

%changelog
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to v2.6.1:
  * delete/refine: fix adjusting indices
  * build(deps): bump github.com/sirupsen/logrus from 1.8.1 to 1.9.0
  * Add environment variable to switch the order of LINEFLAG and file
  * Add missing export for EDITOR
  * simplify test by removing parameter expansion
  * Add vendored dependency google/shlex
  * Tests for vgrep --show .. and various EDITOR values
  * Support opening file at line number in nano
  * Update dependencies
  * Allow passing command with options through the $EDITOR env variable
  * allow ripgrep to use configuration file
  * Dockerfile: use golang:latest
  * make .install.go-md2man: use go install
* Thu Jan 27 2022 Avinesh Kumar <avinesh.kumar@suse.com>
- update to 2.6.0:
  * -l, --files-with-matches
  * Fix 'git grep' color issue
  * fix all selector
  * getGrepType: fix typo
* Mon Jan 24 2022 Dirk Müller <dmueller@suse.com>
- update to 2.5.5:
  * throw an error for unknown grep types
  * make grep-type detection more robust
  * Fix RegEx for grep version type
  * getGrepType: fix typo
  * don't print help message twice
  * CI: use golang:1.17 container
  * performance: user faster json lib
  * log parsing errors
  * --memory-profile
  * bump dependencies
  * add dependabot.yml
  * Fix indentation
  * Fix fzf example
  * Modify fzf example; parse error due to typo
  * write to stdout if it's not a tty
  * bump golangci-lint v1.36.0
  * Review feedback
  * Add fzf wrapper
  * use switch table for dispatcher
* Thu Jan 21 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.5.1:
  * vgrep [no grep args]: print matches
  * Makefile: fix install targets
- Changes for version 2.5.0:
  * New vgrep(1) man page
  * Support vgrep -{A,B,C}
  * Goland support
  * Smaller bug fixes
* Mon Aug 31 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.4.0:
  * selectors: add a "all" selector to process all results
  * splitMatch: fail gracefully on failure to parse output
  * (new) grep: add filename completion
  * (new) grep: add a command to trigger a new search from interactive shell
  * refine: add a command to refine match list based on a regular expression
  * keep: add a new command to keep selected indices
  * show: fix a typo ("douldn't" -> "couldn't")
  * colwriter: prevent panic on --no-header and no result found
  * interactive: close command-line editor on early os.Exit()
  * interactive: switch from bufio Scanner to (readline-like) liner
  * delete: fix index update for multi-line deletions
  * git grep: Run 'git rev-parse' only if not selecting ripgrep
  * grep output: expect no more than 2 substrings when splitting on NUL-byte
  * grep output: force printing filename for grep/ripgrep
  * grep commands: Do not pass '.' as an argument to grep/ripgrep
  * README: mention Homebrew package on Mac OS
* Tue Jul 28 2020 Martin Rey <mrey@suse.com>
- Update to version 2.3.3:
  * When using emacs, also make sure to account for emacs in
    daemon mode and check for emacsclient as an editor.
- Changes from version 2.3.2:
  * emacs support
  * remove requirement to load cache from the same dir
- Changes from version 2.3.1:
  * README: clarify search/show
  * README: add install instructions
  * replace string literals with constants
  * remove redundant flags
  * gnu uses different format than bsd and git grep
  * linter error fix for regex
  * fix #79, define a new greptype bsd to select : seperator
  * use golangci-lint v1.26.0
  * CI: use golang:1.14
  * update dependencies
  * build(deps): bump github.com/sirupsen/logrus from 1.5.0 to
    1.6.0
  * Update chmod command
  * Cross-platform make install
* Wed May 13 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.3.0:
  * pin golangci-lint version
  * Use a standard variable for setting the installation path
  * Ripgrep support
  * Cache file mode 0644
  * drop interactive -i short flag
  * Enable basic functionality on windows
  * build(deps): bump github.com/sirupsen/logrus from 1.4.2 to 1.5.0
  * resolve symlinks in cache
* Fri Apr 17 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.2.0:
  * Changed yellow to magenta to improve readability on light color
    schemes (e.g., tango).
  * Auto-detect VSCode terminal and print line column in a
    clickable format for easy browing.
  * Vgrep has a logo.
* Sun Feb 17 2019 Valentin Rothberg <vrothberg@please-enter-an-email-address>
- Update vgrep to v2.1.0:
  https://github.com/vrothberg/vgrep/releases/tag/2.1.0
  This update includes some bug fixes concurrent accesses to the cache
  can corrupt data.  It also improves parsing of commands and fixes
  some minor bugs related to parsing.
* Sat Jan 27 2018 vrothberg@suse.com
- Update vgrep v2.0.1 to v2.0.2
  https://github.com/vrothberg/vgrep/releases/tag/2.0.2
* Tue Dec 26 2017 jengelh@inai.de
- Avoid fdupes across partitions.
- Trim filler wording from summary.
* Mon Dec 18 2017 vrothberg@suse.com
- Add package for vgrep v2.0.1 (https://github.com/vrothberg/vgrep)
  vgrep is a command-line tool to search textual patterns in directories. It
  serves as a frontend to grep and git-grep and allows to open the indexed
  matching lines in a user-specified editor. vgrep is inspired by the ancient
  cgvg scripts but extended to perform further operations such as listing
  statistics of files and directory trees or showing the context lines before
  and after the matches.
